@@ -28,6 +28,7 @@ import re
 import sys
 
 import pkg_resources
+import setuptools
 from setuptools.command import develop
 from setuptools.command import easy_install
 from setuptools.command import egg_info
@@ -131,6 +132,7 @@ def parse_requirements(requirements_files=None, strip_markers=False):
             reason = 'Index Location'
 
         if line is not None:
+            line = re.sub('#.*$', '', line)
             if strip_markers:
                 semi_pos = line.find(';')
                 if semi_pos < 0:
@@ -202,6 +204,25 @@ class TestrTest(testr_command.Testr):
         testr_command.Testr.run(self)
 
 
+class LocalRPMVersion(setuptools.Command):
+    __doc__ = """Output the rpm *compatible* version string of this package"""
+    description = __doc__
+
+    user_options = []
+    command_name = "rpm_version"
+
+    def run(self):
+        log.info("[pbr] Extracting rpm version")
+        name = self.distribution.get_name()
+        print(version.VersionInfo(name).semantic_version().rpm_string())
+
+    def initialize_options(self):
+        pass
+
+    def finalize_options(self):
+        pass
+
+
 def have_testr():
     return testr_command.have_testr
 
@@ -414,7 +435,7 @@ class LocalEggInfo(egg_info.egg_info):
 
 def _from_git(distribution):
     option_dict = distribution.get_option_dict('pbr')
-    changelog = git._iter_log_oneline(option_dict=option_dict)
+    changelog = git._iter_log_oneline()
     if changelog:
         changelog = git._iter_changelog(changelog)
     git.write_git_changelog(option_dict=option_dict, changelog=changelog)
